@@ -23,36 +23,36 @@ __PACKAGE__->meta->make_immutable;
 sub entries {
     my $self      = shift;
     my $dackup    = $self->dackup;
-    my $cache     = $dackup->cache;
     my $container = $self->container;
     my $prefix    = $self->prefix;
 
     my @entries;
-    foreach my $object ( $container->objects( prefix => $prefix )->all ) {
-        my $key = $object->name;
-        $key =~ s/^$prefix//;
-        my $cachekey
-            = 'cloudfiles:' . $container->name . ':' . $prefix . $key;
-        my $size_md5_hex = $cache->get($cachekey);
-        my ( $size, $md5_hex );
-        if ($size_md5_hex) {
-            ( $size, $md5_hex ) = split ' ', $size_md5_hex;
-        } else {
-            $size    = $object->size || 0;
-            $md5_hex = $object->md5  || '';
-            $cache->set( $cachekey, "$size $md5_hex" );
+    my $stream = $container->objects( prefix => $prefix );
+    until ( $stream->is_done ) {
+        foreach my $object ( $stream->items ) {
+            my $key = $object->name;
+            $key =~ s/^$prefix//;
+            my $entry = Dackup::Entry->new(
+                {   key     => $key,
+                    md5_hex => $object->etag,
+                    size    => $object->size,
+                }
+            );
+            push @entries, $entry;
         }
-        my $entry = Dackup::Entry->new(
-            {   key     => $key,
-                md5_hex => $md5_hex,
-                size    => $size,
-            }
-        );
-        push @entries, $entry;
     }
     return \@entries;
 }
 
+sub object {
+    my ( $self, $entry ) = @_;
+    return $self->container->object(
+        name => $self->prefix . $entry->key,
+        etag => $entry->md5_hex,
+        size => $entry->size,
+    );
+}
+
 sub name {
     my ( $self, $entry ) = @_;
     return
@@ -65,36 +65,27 @@ sub name {
 sub update {
     my ( $self, $source, $entry ) = @_;
     my $container   = $self->container;
-    my $cache       = $self->dackup->cache;
     my $prefix      = $self->prefix;
     my $source_type = ref($source);
+    my $object      = $self->object($entry);
+
     if ( $source_type eq 'Dackup::Target::Filesystem' ) {
-        $container->put_filename( $prefix . $entry->key,
-            $source->filename($entry) );
+        $object->put_filename( $source->filename($entry) );
     } elsif ( $source_type eq 'Dackup::Target::S3' ) {
         my $filename      = tmpnam();
         my $source_object = $source->object($entry);
         $source_object->get_filename($filename);
-        $container->put_filename( $prefix . $entry->key, $filename );
+        $object->put_filename( $filename );
         unlink($filename) || die "Error deleting $filename: $!";
     } else {
         confess "Do not know how to update from $source_type";
     }
-    my $cachekey
-        = 'cloudfiles:' . $container->name . ':' . $prefix . $entry->key;
-    $cache->delete($cachekey);
-    $cache->set( $cachekey, $entry->size . ' ' . $entry->md5_hex );
 }
 
 sub delete {
     my ( $self, $entry ) = @_;
-    my $container = $self->container;
-    my $prefix    = $self->prefix;
-    my $object    = $container->object( $prefix . $entry->key );
+    my $object = $self->object($entry);
     $object->delete;
-    my $cachekey
-        = 'cloudfiles:' . $container->name . ':' . $prefix . $entry->key;
-    $self->dackup->cache->delete($cachekey);
 }
 
 1;
